@@ -51,6 +51,7 @@ class SASconfigHTTP:
       self._token    = cfg.get('authtoken', None)
       self._refresh  = cfg.get('refreshtoken', None)
       self.url       = cfg.get('url', '')
+      self.proxy     = cfg.get('proxy', None)
       self.serverid  = cfg.get('serverid', None)
       self.ip        = cfg.get('ip', '')
       self.port      = cfg.get('port', None)
@@ -94,6 +95,13 @@ class SASconfigHTTP:
       self.verbose = self.cfgopts.get('verbose', True)
       self.verbose = kwargs.get('verbose', self.verbose)
 
+      inproxy = kwargs.get('proxy', None)
+      if inproxy is not None:
+         if lock and len(self.proxy):
+            logger.warning("Parameter 'proxy' passed to SAS_session was ignored due to configuration restriction.")
+         else:
+            self.proxy = inproxy
+
       inurl = kwargs.get('url', None)
       if inurl is not None:
          if lock and len(self.url):
@@ -120,7 +128,7 @@ class SASconfigHTTP:
          if lock and self.port:
             logger.warning("Parameter 'port' passed to SAS_session was ignored due to configuration restriction.")
          else:
-            self.port = inport
+            self.port = int(inport)
 
       inctxname = kwargs.get('context', None)
       if inctxname is not None:
@@ -136,20 +144,6 @@ class SASconfigHTTP:
          else:
             self.options = inoptions
 
-      inssl = kwargs.get('ssl', None)
-      if inssl is not None:
-         if lock and self.ssl:
-            logger.warning("Parameter 'ssl' passed to SAS_session was ignored due to configuration restriction.")
-         else:
-            self.ssl = bool(inssl)
-
-      inver = kwargs.get('verify', None)
-      if inver is not None:
-         if lock and self.verify:
-            logger.warning("Parameter 'verify' passed to SAS_session was ignored due to configuration restriction.")
-         else:
-            self.verify = bool(inver)
-
       intout = kwargs.get('timeout', None)
       if intout is not None:
          if lock and self.timeout:
@@ -224,12 +218,26 @@ class SASconfigHTTP:
          else:
             self.authkey = inak
 
+      inssl = kwargs.get('ssl', None)
+      if inssl is not None:
+         if lock and self.ssl:
+            logger.warning("Parameter 'ssl' passed to SAS_session was ignored due to configuration restriction.")
+         else:
+            self.ssl = bool(inssl)
+
+      inver = kwargs.get('verify', None)
+      if inver is not None:
+         if lock and self.verify:
+            logger.warning("Parameter 'verify' passed to SAS_session was ignored due to configuration restriction.")
+         else:
+            self.verify = bool(inver)
+
       if len(self.url) > 0:
          http = self.url.split('://')
          hp   = http[1].split(':')
          if http[0].lower() in ['http', 'https']:
             self.ip   = hp[0]
-            self.port = hp[1] if len(hp) > 1 else self.port
+            self.port = int(hp[1]) if len(hp) > 1 else self.port
             self.ssl  = True if 's' in http[0].lower() else False
          else:
             logger.warning("Parameter 'url' not in recognized format. Expeting 'http[s]://host[:port]'. Ignoring parameter.")
@@ -309,7 +317,7 @@ class SASconfigHTTP:
             if len(self.url) > 0:
                purl = self.url+purl
             else:
-               purl = "http{}://{}:{}{}".format('s' if self.ssl else '', self.ip, self.port, purl)
+               purl = "http{}://{}:{}{}".format('s' if self.ssl else '', self.ip, str(self.port), purl)
             msg  = "The default url to authenticate with would be {}\n".format(purl)
             msg += "Please enter authcode: "
             authcode = self._prompt(msg)
@@ -329,6 +337,23 @@ class SASconfigHTTP:
                   self._token = None
                   raise RuntimeError("No password provided.")
 
+      if self.proxy is not None:
+         http = self.proxy.split('://')
+         if http[0].lower() in ['http', 'https']:
+            hp = http[1].split(':')
+         else:
+            hp = http[0].split(':')
+
+         self.pip   = self.ip
+         self.ip    = hp[0]
+         self.pport = self.port
+         self.port  = int(hp[1]) if len(hp) > 1 else self.port
+
+         #else:
+         #   logger.warning("Parameter 'proxy' not in recognized format. Expeting '[http[s]://]host:port'. Ignoring parameter.")
+      else:
+         self.pip = None
+
       # get Connections
       if self.ssl:
          if self.verify:
@@ -348,6 +373,10 @@ class SASconfigHTTP:
          self.REFConn  = hc.HTTPConnection(self.ip, self.port, timeout=self.timeout)
          self.HTTPConn = hc.HTTPConnection(self.ip, self.port, timeout=self.timeout)
 
+      if self.pip:
+         self.REFConn.set_tunnel( self.pip, self.pport)
+         self.HTTPConn.set_tunnel(self.pip, self.pport)
+
       # get AuthToken
       if not self._token:
          js = self._authenticate(user, pw, authcode, client_id, client_secret, jwt)
