@@ -512,10 +512,11 @@ class SASstat:
 
     @procDecorator.proc_decorator({})
     def factor(self, data: ('SASdata', str) = None,
-               by: str = None,
-               cls: (str, list) = None,
+               by: (str, list) = None,
                freq: str = None,
-               paired: str = None,
+               partial: str = None,
+               pathdiagram: str = None,
+               priors: str = None,
                var: str = None,
                weight: str = None,
                procopts: str = None,
@@ -527,14 +528,52 @@ class SASstat:
         Documentation link:
         https://go.documentation.sas.com/?cdcId=pgmsascdc&cdcVersion=9.4_3.4&docsetId=statug&docsetTarget=statug_factor_syntax.htm&locale=en
 
-        :param data: SASdata object or string. This parameter is required.
-        :parm by: The by variable can only be a string type.
-        :parm cls: The cls variable can be a string or list type. It refers to the categorical, or nominal variables.
+        :param data: SASdata object or string. This parameter is required..
+        :parm by: The by variable can be a string or list type. 
         :parm freq: The freq variable can only be a string type.
-        :parm paired: The paired variable can only be a string type.
+        :parm partial: The partial variable can only be a string type.
+        :parm pathdiagram: The pathdiagram variable can only be a string type.
+        :parm priors: The priors variable can only be a string type.
         :parm var: The var variable can only be a string type.
         :parm weight: The weight variable can only be a string type.
         :parm procopts: The procopts variable is a generic option available for advanced use. It can only be a string type.
         :parm stmtpassthrough: The stmtpassthrough variable is a generic option available for advanced use. It can only be a string type.
         :return: SAS Result Object
         """
+
+    @procDecorator.proc_decorator({})
+    def mi(self, data: ('SASdata', str) = None,
+           by: (str, list) = None,
+           cls: (str, list) = None,
+           em: str = None,
+           fcs: str = None,
+           freq: str = None,
+           mcmc: str = None,
+           mnar: str = None,
+           monotone: str = None,
+           transform: str = None,
+           var: str = None,
+           procopts: str = None,
+           stmtpassthrough: str = None,
+           **kwargs: dict) -> 'SASresults':
+        """
+        Python method to call the MI procedure.
+
+        Documentation link:
+        https://go.documentation.sas.com/doc/en/statug/15.2/statug_mi_toc.htm
+
+        :param data: SASdata object or string. This parameter is required.
+        :parm by: The by variable can be a string or list type.
+        :parm cls: The cls variable can be a string or list type. It refers to the categorical, or nominal variables.
+        :parm em: The em variable can only be a string type.
+        :parm fcs: The fcs variable can only be a string type.
+        :parm freq: The freq variable can only be a string type.
+        :parm mcmc: The mcmc variable can only be a string type.
+        :parm mnar: The mnar variable can only be a string type.
+        :parm monotone: The monotone variable can only be a string type.
+        :parm transform: The transform variable can only be a string type.
+        :parm var: The var variable can only be a string type.
+        :parm procopts: The procopts variable is a generic option available for advanced use. It can only be a string type.
+        :parm stmtpassthrough: The stmtpassthrough variable is a generic option available for advanced use. It can only be a string type.
+        :return: SAS Result Object
+        """
